@@ -1,4 +1,4 @@
 #! /usr/bin/env python
 
-from unittest2.main import main
+from unittest2 import main
 main(module=None)
\ No newline at end of file
