@@ -17,6 +17,8 @@ class TestResult(unittest.TestResult):
     contain tuples of (testcase, exceptioninfo), where exceptioninfo is the
     formatted traceback of the error that occurred.
     """
+    _previousTestClass = None
+    _moduleSetUpFailed = False
     def __init__(self):
         self.failures = []
         self.errors = []
@@ -25,7 +27,7 @@ class TestResult(unittest.TestResult):
         self.expectedFailures = []
         self.unexpectedSuccesses = []
         self.shouldStop = False
-
+    
     def startTest(self, test):
         "Called when the given test is about to be run"
         self.testsRun += 1
